pub async fn create_embeddings(
app_config: &ApplicationConfiguration,
inputs: Vec<String>,
) -> UtilResult<Vec<Vec<f32>>>Expand description
Creates an embedding vector for each string passed as an argument.
pub async fn create_embeddings(
app_config: &ApplicationConfiguration,
inputs: Vec<String>,
) -> UtilResult<Vec<Vec<f32>>>Creates an embedding vector for each string passed as an argument.